@@ -1,3 +1,3 @@
 from .json_object import JsonObject, JsonList, JsonDate, JsonString
-from .decorators import json_force_parameter_type, json_parameters, json_parameters, json_parse
+from .decorators import json_force_parameter_type, json_parameters, json_parameters, json_parse, json_get_parameters
 from .search import SortOrder, SearchType, NotFoundBehavior
\ No newline at end of file
